/**
 * @file
 */

(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.global = {
    attach: function (context, settings) {
      // When Click on the checkbox add class to the sibling label selectedStyle
      $(".fieldset-wrapper input[type=radio]").on("click", function () {
        $(this)
          .parent()
          .parent()
          .find("input[type=radio]")
          .each(function () {
            $(this).parent().find("label").removeClass("selectedStyle");
          });
        $(this).parent().find("label").addClass("selectedStyle");
      });

      $("#seeds-container li a").each(function () {
        $(this).on("click", function () {
          $("#seeds-container li a").removeClass("active");
          $(this).toggleClass("active");
          var href = $(this).attr("data-target");
          if (href && $("#seeds-body").length) {
            $(".seeds-body-item").removeClass("active");
            $(".seeds-body--" + href).addClass("active");
          }
        });
      });
    },
  };
  Drupal.behaviors.add_section = {
    attach: function (context, settings) {
      // Select all elements with the layout-builder__section class
      var sectionElements = document.querySelectorAll(
        ".layout-builder__section"
      );
      // Add event listeners for each section element
      sectionElements.forEach(function (sectionElement) {
        sectionElement.addEventListener("mouseenter", function () {
          // Get the previous and next sibling elements
          var prevSibling = sectionElement.previousElementSibling;
          var nextSibling = sectionElement.nextElementSibling;

          // Add the 'highlight' class to the previous sibling if it has the right class
          if (
            prevSibling &&
            prevSibling.classList.contains("layout-builder__add-section")
          ) {
            prevSibling.classList.add("highlight");
          }

          // Add the 'highlight' class to the next sibling if it has the right class
          if (
            nextSibling &&
            nextSibling.classList.contains("layout-builder__add-section")
          ) {
            nextSibling.classList.add("highlight");
          }
        });

        sectionElement.addEventListener("mouseleave", function () {
          // Get the previous and next sibling elements
          var prevSibling = sectionElement.previousElementSibling;
          var nextSibling = sectionElement.nextElementSibling;

          // Remove the 'highlight' class from the previous sibling if it has the right class
          if (
            prevSibling &&
            prevSibling.classList.contains("layout-builder__add-section")
          ) {
            prevSibling.classList.remove("highlight");
          }

          // Remove the 'highlight' class from the next sibling if it has the right class
          if (
            nextSibling &&
            nextSibling.classList.contains("layout-builder__add-section")
          ) {
            nextSibling.classList.remove("highlight");
          }
        });
      });
    },
  };

  Drupal.behaviors.active_view_mode = {
    attach: function (context, settings) {
      var viewModesElements = document.querySelectorAll(
        ".field--name-field-seeds-view-mode .seeds--lb-form-item"
      );

      viewModesElements.forEach(function (viewModeElement) {
        var lastChild = viewModeElement.lastElementChild;
        lastChild.addEventListener("click", function () {
          // Remove 'active' class from all lastChild elements
          viewModesElements.forEach(function (viewModeElement) {
            viewModeElement.lastElementChild.classList.remove("active");
          });

          // Add 'active' class to the clicked lastChild
          lastChild.classList.add("active");
        });
      });
    },
  };
  Drupal.behaviors.active_paragraph_dropdown = {
    attach: function (context, settings) {
      var tableElements = document.querySelectorAll(
        ".layout-builder-add-block .field-multiple-table tbody tr,.layout-builder-add-block .field--type-entity-reference-revisions "
      );

      tableElements.forEach(function (tableElement) {
        let paragraphTypeTop = tableElement.querySelectorAll(
          ".paragraph-type-top"
        );

        once("active_paragraph_dropdown", paragraphTypeTop, context).forEach(
          function (el) {
            el.addEventListener("click", function () {
              if (
                el.classList.contains("active") &&
                el.nextElementSibling.classList.contains("active")
              ) {
                el.classList.remove("active");
                el.nextElementSibling.classList.remove("active");
              } else {
                // Remove 'active' class from all elements
                var allparagraphTypeTop = document.querySelectorAll(
                  ".paragraph-type-top"
                );

                allparagraphTypeTop.forEach(function (item) {
                  item.classList.remove("active");
                });

                // Remove 'active' class from all subforms
                var allSubforms = document.querySelectorAll(
                  ".paragraphs-subform"
                );
                allSubforms.forEach(function (subform) {
                  subform.classList.remove("active");
                });

                // Add 'active' class to the clicked element
                el.classList.toggle("active");

                // Add 'active' class to the next sibling if it exists and has the 'paragraphs-subform' class
                var nextSibling = el.nextElementSibling;
                if (
                  nextSibling &&
                  nextSibling.classList.contains("paragraphs-subform")
                ) {
                  nextSibling.classList.toggle("active");
                }
              }
            });
          }
        );
      });
    },
  };
})(jQuery, Drupal, drupalSettings);
